@@ -1,19 +1,9 @@
 import importlib
 import os
 import sys
-from turpy.logger import log
-from typing import List
-import re
-
-
-def string_search_in_list(input_string:str, searching_list:List[str]):
-    """List of items where a particular string matches (case insensitive) items in a list of strings.
-    
-    :returns: items in list where there was a match
-
-    """
-    r = re.compile(input_string, re.IGNORECASE)
-    return list(filter(r.search, searching_list))
+import logging
+logging.basicConfig(
+    format=' % (asctime)s | %(name)s | %(levelname)s | %(message)s', level=40)
 
 
 def script_as_module(module_filepath: str, package_path: str = './project/services/'):
@@ -42,7 +32,7 @@ def script_as_module(module_filepath: str, package_path: str = './project/servic
     try:
         module = importlib.util.module_from_spec(spec)
     except Exception as e:
-        log.error(e)
+        logging.error(e)
         return False
     else:
         spec.loader.exec_module(module)
